Re-exports
pub use shared::error::CallerError;pub use domain::auth_registry::AuthRegistry;pub use domain::auth_trait::AuthContext;pub use domain::auth_trait::AuthProvider;pub use domain::auth_trait::Authenticator;pub use domain::builtin_auth::ApiKeyAuth;pub use domain::builtin_auth::BasicAuth;pub use domain::builtin_auth::BearerAuth;pub use domain::builtin_auth::CustomHeaderAuth;pub use domain::builtin_auth::DynamicApiKeyAuth;pub use domain::builtin_auth::DynamicBearerAuth;pub use domain::builtin_auth::DynamicHeaderAuth;pub use domain::builtin_auth::NoAuth;pub use domain::builtin_auth::OAuth2Auth;pub use openapi::OpenApiDoc;pub use openapi::OpenApiGenerator;pub use server::ServerConfig;pub use config::*;pub use domain::*;pub use params::*;
Modules
- config
- core
- domain
- infra
- openapi
- OpenAPI specification generation for Caller
- params
- 参数构建器模块 提供类型安全的参数传递方式,替代 HashMap<String, String>
- server
- HTTP server for Swagger UI and API proxy
- shared
Macros
- json_
params - 从 serde_json::Value 创建参数的快捷方式
- params
- 方便创建参数的宏
Functions
- auth_
count - Get the number of registered authentication providers
- call
- Main public API function
- call_
params - Main public API function with type-safe parameters
- call_
params_ with_ retry - Main public API function with type-safe parameters and retry support
- call_
with_ retry - Main public API function with retry support
- clear_
auth - Clear all registered authentication providers
- download
- Download file from API endpoint
- download_
params - Download file from API endpoint with type-safe parameters
- has_
auth - Check if an authentication provider is registered
- init_
config - Initialize the configuration by loading from file
- is_
config_ loaded - Check if the configuration is loaded
- is_
watching_ config - Check if the config is currently being watched
- list_
auth - List all registered authentication provider names
- register_
auth - Register an authenticator implementation
- register_
auth_ closure - Register a closure-based authentication provider
- reload_
config - Manually reload the configuration from file
- remove_
auth - Remove an authentication provider
- stop_
watch_ config - Stop watching the config file
- update_
auth - Update an existing authenticator
- update_
auth_ closure - Update a closure-based authentication provider
- watch_
config - Start watching the config file for changes. Changes will be automatically reloaded with a default debounce of 500ms.
- watch_
config_ with_ debounce - Start watching the config file with a custom debounce duration